/**
 * Copyright 2022 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

output "address" {
  description = "VPN gateway address."
  value       = local.gateway_address
}

output "gateway" {
  description = "VPN gateway resource."
  value       = google_compute_vpn_gateway.gateway
}

output "id" {
  description = "Fully qualified VPN gateway id."
  value       = google_compute_vpn_gateway.gateway.id
}

output "name" {
  description = "VPN gateway name."
  value       = google_compute_vpn_gateway.gateway.name
}

output "random_secret" {
  description = "Generated secret."
  value       = local.secret
}


output "router" {
  description = "Router resource (only if auto-created)."
  value       = one(google_compute_router.router[*])
}

output "router_name" {
  description = "Router name."
  value       = local.router
}

output "self_link" {
  description = "VPN gateway self link."
  value       = google_compute_vpn_gateway.gateway.self_link
}

output "tunnel_names" {
  description = "VPN tunnel names."
  value = {
    for name in keys(var.tunnels) :
    name => try(google_compute_vpn_tunnel.tunnels[name].name, null)
  }
}

output "tunnel_self_links" {
  description = "VPN tunnel self links."
  value = {
    for name in keys(var.tunnels) :
    name => try(google_compute_vpn_tunnel.tunnels[name].self_link, null)
  }
}

output "tunnels" {
  description = "VPN tunnel resources."
  value = {
    for name in keys(var.tunnels) :
    name => try(google_compute_vpn_tunnel.tunnels[name], null)
  }
}
